@@ -29,6 +29,7 @@ class filesListManager:
     def check_files_list_key(self,key):
         if key not in self.files_list_dict:
             self.files_list_dict[key]=[]
+        return self.files_list_dict[key]
     def clear_list(self,key):
         self.files_list_dict[key]=[]
         return []
@@ -43,14 +44,15 @@ class filesListManager:
             display_name = file_refference['filename'] if file_names_dict[file_name] == 0 else f"{file_refference['filename']} ({file_names_dict[file_name]})"
             self.files_list_dict[key][i]['display_name'] = display_name
     def is_display_name(self,key,display_name):
-        for i,file_refference in enumerate(self.files_list_dict[key]):
+        for i,file_refference in enumerate(self.check_files_list_key(key)):
             if display_name == file_refference['display_name']:
                 return i
         return display_name
+    
     def add_to_files_list_dict(self,key,file_path):
         directory = os.path.dirname(file_path)
         filename = os.path.basename(file_path)
-        for i,file_refference in enumerate(self.files_list_dict[key]):
+        for i,file_refference in enumerate(self.check_files_list_key(key)):
             if file_refference['filepath'] == file_path:
                 return
         self.files_list_dict[key].append({"dirname":directory,"filename":filename,"filepath":file_path,"display_name":filename})
@@ -90,7 +92,7 @@ class filesListManager:
         return self.files_list_dict[key][display_number]['filepath']
     def get_file_path_list(self,key):
         path_list = []
-        for file_refference in self.files_list_dict[key]:
+        for file_refference in self.check_files_list_key(key):
             path_list.append(file_refference['filepath'])
         return path_list
 class AbstractBrowser:
@@ -152,23 +154,20 @@ class AbstractBrowser:
         listboxes_layout=[]
         listboxes_layout.append(sg.Frame('browser',layout=ensure_nested_list([[sg.Listbox(values=[], size=(50, 10), key=text_to_key(text='browser list',section=section), enable_events=True)],
                                                                              [sg.Push(),sg.Button('<-', key=text_to_key(text='browse backwards',section=section)),
-                                                                              sg.Button('->', key=text_to_key(text='browse forwards',section=section)),sg.Push()]])))
+                                                                              sg.Button('Scan', key=text_to_key(text='scan',section=section)),
+                                                                              sg.Button('->', key=text_to_key(text='browse forwards',section=section)),sg.Button('ADD', key=text_to_key(text='add_to_list',section=section)),sg.Push()]])))
+
         listboxes_layout.append(sg.Frame('files',layout=ensure_nested_list([[sg.Listbox(values=[], size=(50, 10), key=text_to_key(text='files list',section=section), enable_events=True)],
-                                                                             [sg.Push(),sg.Button('UP', key=text_to_key(text='move up list',section=section)),
-                                                                              sg.Button('DOWN', key=text_to_key(text='move down list',section=section)),sg.Push()]])))
+                                                                             [sg.Push(),sg.Button('UP', key=text_to_key(text='move up list',section=section)),sg.Button('DOWN', key=text_to_key(text='move down list',section=section)),
+                                                                              sg.Button('REMOVE', key=text_to_key(text='remove from list',section=section)),
+                                                                              sg.Button('Clear', key=text_to_key(text='clear list',section=section)),sg.Push()]])))
 
-        control_buttons_layout = [
-            sg.Button('Scan', key=text_to_key(text='scan',section=section)),
-            sg.Button('Clear', key=text_to_key(text='clear list',section=section)),
-            sg.Button('ADD', key=text_to_key(text='add_to_list',section=section)),
-            sg.Button('REMOVE', key=text_to_key(text='remove from list',section=section))
-        ] + extra_buttons
-
-        return [[sg.Text('Directory to scan:'), sg.InputText(os.getcwd(),key=text_to_key(text='dir',section=section)),sg.FolderBrowse('Folders', key=text_to_key(text='directory browser',section=section)),sg.FileBrowse('Files', key=text_to_key(text='file browser',section=section))],
-            [sg.Column([listboxes_layout,browser_buttons_layout])],
-            control_buttons_layout
-        ]
 
+        layout = [[sg.Text('Directory to scan:'), sg.InputText(os.getcwd(),key=text_to_key(text='dir',section=section)),sg.FolderBrowse('Folders', key=text_to_key(text='directory browser',section=section)),sg.FileBrowse('Files', key=text_to_key(text='file browser',section=section))],
+            [sg.Column([listboxes_layout,browser_buttons_layout])]]
+        if extra_buttons:
+            layout.append(extra_buttons)         
+        return layout
     def while_static(self,event_key_js,values,window):
         self.event_key_js,self.values,self.window=event_key_js,values,window
         self.section_key = key = self.event_key_js['section']
@@ -232,7 +231,7 @@ class AbstractBrowser:
                 self.files_list_mgr.add_to_files_list_dict(self.section_key,file_path)
                 self.window[self.event_key_js['-FILES_LIST-']].update(self.files_list_mgr.return_display_names(self.section_key))
         if self.event_key_js['found'] == '-CLEAR_LIST-':
-            self.window[self.event_key_js['-FILES_LIST-']].update(clear_list(self,key))
+            self.window[self.event_key_js['-FILES_LIST-']].update(self.files_list_mgr.clear_list(key))
         if self.event_key_js['found'] == "-BROWSE_BACKWARDS-":
             # Navigate up to the parent directory
             if self.return_directory() not in self.history:
